==> tpcclib-0.7.9-src.tar.gz: v2/libtpcli/test_tpcli.h <==
#ifndef _TEST_TPCLI_H_
#define _TEST_TPCLI_H_
/*****************************************************************************/

/*****************************************************************************/
#include "tpcclibConfig.h"
/*****************************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <math.h>
/*****************************************************************************/
#include "tpcmodels.h"
#include "tpcfunc.h"
#include "tpcpar.h"
/*****************************************************************************/
#include "tpcli.h"
/*****************************************************************************/

/*****************************************************************************/
/* interpolate */
extern int pol3eval(
  double *pp, double x1, double x2, double *y, double *yi, double *yii
);
extern int test_liFirstStepSize(TPCSTATUS *status);
extern int test_simSamples(TPCSTATUS *status);
extern int test_liInterpolate(TPCSTATUS *status);
extern int test_liInterpolateForPET(TPCSTATUS *status);
extern int test_liFrameMidValue(TPCSTATUS *status);
/*****************************************************************************/
/* integrate */
extern int test_liIntegrate(TPCSTATUS *status);
extern int test_liIntegratePET(TPCSTATUS *status);
extern int test_liIntegrateHalfFrame(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
#endif /* TEST_TPCLI */

==> tpcclib-0.8.0-src.tar.gz: v2/libtpcli/test_tpcli.h <==
#ifndef _TEST_TPCLI_H_
#define _TEST_TPCLI_H_
/*****************************************************************************/

/*****************************************************************************/
#include "tpcclibConfig.h"
/*****************************************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <math.h>
/*****************************************************************************/
#include "tpcmodels.h"
#include "tpcfunc.h"
#include "tpcpar.h"
/*****************************************************************************/
#include "tpcli.h"
/*****************************************************************************/

/*****************************************************************************/
/* interpolate */
extern int pol3eval(
  double *pp, double x1, double x2, double *y, double *yi, double *yii
);
extern int test_liFirstStepSize(TPCSTATUS *status);
extern int test_simSamples(TPCSTATUS *status);
extern int test_liInterpolate(TPCSTATUS *status);
extern int test_liInterpolateForPET(TPCSTATUS *status);
//extern int test_liFrameMidValue(TPCSTATUS *status);
/*****************************************************************************/
/* integrate */
extern int test_liIntegrate(TPCSTATUS *status);
extern int test_liIntegratePET(TPCSTATUS *status);
extern int test_liIntegrateFE(TPCSTATUS *status);
extern int test_liIntegrateHalfFrame(TPCSTATUS *status);
/*****************************************************************************/

/*****************************************************************************/
#endif /* TEST_TPCLI */
